@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,13 +32,12 @@ __u32 option;
 unsigned int quota_id;
 char *mount_point = NULL;
 char *config_file = NULL;
+char *actual_config_file = NULL;	/* path to actually used config file */
 
 struct vz_quota_stat limits;
-#ifdef L2
 //struct vz_quota_stat ugid_limits;
 struct vz_quota_ugid_stat ug_config;
 //int ugid;
-#endif
 
 int debug_level = 0;
 int batch_mode = 0;
@@ -138,7 +137,6 @@ void *xmalloc(size_t size)
 	return (ptr);
 }
 
-#ifdef L2
 void *xrealloc(void *p, size_t size)
 {
 	void *ptr;
@@ -147,7 +145,6 @@ void *xrealloc(void *p, size_t size)
 		error(EC_SYSTEM, errno, "not enough memory for %d bytes", size);
 	return (ptr);
 }
-#endif
 
 char *xstrdup(const char* s)
 {
@@ -160,29 +157,34 @@ char *xstrdup(const char* s)
 
 int str2uint(char *str, unsigned int *number)
 {
+	char *p;
+
 	ASSERT(str && number);
-	if (sscanf(str, "%u", number) != 1)
+	*number = strtol(str, &p, 10);
+	if (*str == '\0' || *p != '\0')
 		return -1;
 	return 0;
 }
 
 int str2u32(char *str, __u32 * number)
 {
-	unsigned int i;
+	char *p;
+
 	ASSERT(str && number);
-	if (sscanf(str, "%u", &i) != 1)
+	*number = strtol(str, &p, 10);
+	if (*str == '\0' || *p != '\0')
 		return -1;
-	*number = i;
 	return 0;
 }
 
 int str2u64(char *str, __u64 * number)
 {
-	unsigned long long i;
+	char *p;
+
 	ASSERT(str && number);
-	if (sscanf(str, "%llu", &i) != 1)
+	*number = strtoll(str, &p, 10);
+	if (*str == '\0' || *p != '\0')
 		return -1;
-	*number = i;
 	return 0;
 }
 
@@ -420,9 +422,7 @@ int parse_options(int argc, char **argv, char *short_options,
 
 	option = 0;
 	memset(&limits, 0, sizeof(limits));
-#ifdef L2
 	memset(&ug_config, 0, sizeof(ug_config));
-#endif
 
 	if (argc < 2)
 		/* cmd <veid> */
@@ -447,32 +447,6 @@ int parse_options(int argc, char **argv, char *short_options,
 			option |= FL_NOCHECK;
 			 break;
 
-#ifndef L2
-		case 'r':
-			if (!strcmp(optarg, "1")) {
-				option |= FL_RSQ;
-				limits.options |= VZ_QUOTA_OPT_RSQUASH;
-			} else if (!strcmp(optarg, "0")) {
-				option |= FL_RSQ;
-				limits.options &= (~VZ_QUOTA_OPT_RSQUASH);
-			} else {
-				usage(opt_usage);
-			}
-			break;
-
-		case 's':
-			if (!strcmp(optarg, "1")) {
-				option |= FL_SQT;
-				limits.options |= VZ_QUOTA_OPT_SUBQUOTAS;
-			} else if (!strcmp(optarg, "0")) {
-				option |= FL_SQT;
-				limits.options &=
-					(~VZ_QUOTA_OPT_SUBQUOTAS);
-			} else {
-				usage(opt_usage);
-			}
-			break;
-#else
 		case 'r':
 			break;
 
@@ -520,7 +494,6 @@ int parse_options(int argc, char **argv, char *short_options,
 		case 'T':
 			option |= FL_DUMP_EXPTIME;
 			break;
-#endif
 		case 'c':
 			option |= FL_CONF_FILE;
 			config_file = optarg;
@@ -536,71 +509,54 @@ int parse_options(int argc, char **argv, char *short_options,
 			break;
 
 		case 'b':
-#ifndef L2
-			if (str2u64(optarg, &limits.bsoftlimit) < 0)
-#else
 			if (str2u64(optarg, &limits.dq_stat.bsoftlimit) < 0)
-#endif
 				usage(opt_usage);
 			option |= FL_BSL;
 			break;
 
 		case 'B':
-#ifndef L2
-			if (str2u64(optarg, &limits.bhardlimit) < 0)
-#else
 			if (str2u64(optarg, &limits.dq_stat.bhardlimit) < 0)
-#endif
 				usage(opt_usage);
 			option |= FL_BHL;
 			break;
 
 		case 'e':
-#ifndef L2
-			if (str2time(optarg, &limits.bexpire) < 0)
-#else
 			if (str2time(optarg, &limits.dq_info.bexpire) < 0)
-#endif
 				usage(time_usage);
 			option |= FL_BET;
 			break;
 
 		case 'i':
-#ifndef L2
-			if (str2u32(optarg, &limits.isoftlimit) < 0)
-#else
 			if (str2u32(optarg, &(limits.dq_stat.isoftlimit)) < 0)
-#endif
 				usage(opt_usage);
 			option |= FL_ISL;
 			break;
 
 		case 'I':
-#ifndef L2
-			if (str2u32(optarg, &limits.ihardlimit) < 0)
-#else
 			if (str2u32(optarg, &(limits.dq_stat.ihardlimit)) < 0)
-#endif
 				usage(opt_usage);
 			option |= FL_IHL;
 			break;
 
 		case 'n':
-#ifndef L2
-			if (str2time(optarg, &limits.iexpire) < 0)
-#else
 			if (str2time(optarg, &limits.dq_info.iexpire) < 0)
-#endif
 				usage(time_usage);
 			option |= FL_IET;
 			break;
 
+		case 'R':
+			option |= FL_RELATIVE;
+			break;
+
 		case '?':
 		default:
 			usage(opt_usage);
 		}
 	}
 
+	if ((option & FL_RELATIVE) && (option & FL_CONF_FILE))
+		error(EC_USAGE, 0, "-c and -R options can't be set together\n");
+
 	return optind;
 }
 
